@@ -1,19 +1,11 @@
 from django.core.urlresolvers import reverse
-from django.utils.safestring import mark_safe
-from django.contrib.admin.util import unquote, flatten_fieldsets, get_deleted_objects, model_ngettext, model_format_dict
+from django.contrib.admin.util import unquote
 from django.utils.translation import ugettext  as _
 from django.http import HttpResponseRedirect
-from django.template import RequestContext
-from django.shortcuts import render_to_response
-from django.contrib import admin
 from django import forms
-from django.db.models import Q
 from filer.admin.permissions import PrimitivePermissionAwareModelAdmin
-from filer.models import Folder, FolderRoot, UnfiledImages, ImagesWithMissingData, File
-from filer.admin.tools import *
-from filer.models import tools
+from filer.models import File
 
-from django.conf import settings
 # forms
 class FileAdminChangeFrom(forms.ModelForm):
     class Meta:
@@ -23,22 +15,26 @@ class FileAdminChangeFrom(forms.ModelForm):
 class FileAdmin(PrimitivePermissionAwareModelAdmin):
     list_display = ('label',)
     list_per_page = 10
-    search_fields = ['name', 'original_filename',]
-    raw_id_fields = ('owner',) #'contact', 
+    search_fields = ['name', 'original_filename','sha1',]
+    raw_id_fields = ('owner',)
+    readonly_fields = ('sha1',)
     
     # save_as hack, because without save_as it is impossible to hide the 
     # save_and_add_another if save_as is False.
     # To show only save_and_continue and save in the submit row we need save_as=True
     # and in render_change_form() override add and change to False.
-    save_as=True
+    save_as = True
     
     form = FileAdminChangeFrom
     fieldsets = (
         (None, {
-            'fields': ('name', 'owner','description')#'contact',
+            'fields': ('name', 'owner','description')
+        }),
+        (None, {
+            'fields': ('is_public',)
         }),
         (_('Advanced'), {
-            'fields': ('_file',),
+            'fields': ('file','sha1',),
             'classes': ('collapse',),
         }),
     )
