@@ -4,6 +4,7 @@ from PIL import Image as PILImage
 from django.utils.translation import ugettext_lazy as _
 from django.core import urlresolvers
 from django.db import models
+from easy_thumbnails.files import Thumbnailer
 from filer.models.filemodels import File
 from filer.utils.pil_exif import get_exif_for_file
 from filer import settings as filer_settings
@@ -165,8 +166,23 @@ class Image(File):
         return urlresolvers.reverse('admin:filer_image_change', args=(self.id,))
     @property
     def easy_thumbnails_relative_name(self):
+        """
+        Return the relative url of the image so easy_thumbnails<=1.0-alpha-16 can work with this model as
+        if it were a file field.
+        """
         return self.rel_image_url
 
+    @property
+    def easy_thumbnails_thumbnailer(self):
+        """
+        Return the relative url of the image so easy_thumbnails>=1.0-alpha-17 can work with this model as
+        if it were a file field.
+        """
+        tn = Thumbnailer(file=self.file.file, name=self.file.name,
+                         source_storage=self.file.source_storage,
+                         thumbnail_storage=self.file.thumbnail_storage)
+        return tn
+
     class Meta:
         app_label = 'filer'
         verbose_name = _('Image')
