@@ -4,7 +4,7 @@ PACKAGE_ROOT = os.path.abspath( os.path.join(os.path.dirname(__file__), '../') )
 PROJECT_ROOT = os.path.join(PACKAGE_ROOT, 'filer')
 TMP_ROOT = os.path.abspath( os.path.join(PACKAGE_ROOT, 'tmp') )
 DATABASE_ENGINE = 'sqlite3'
-DATABASE_NAME = os.path.join(TMP_ROOT,'filer_test.db') # won't actually be used. tests under SQLite are run in-memory
+DATABASE_NAME = 'db.sqlite3'
 INSTALLED_APPS = [
     'filer',
     'mptt',
@@ -15,4 +15,5 @@ INSTALLED_APPS = [
     'django.contrib.sessions',]
 ROOT_URLCONF = 'filer.testurls'
 
-MEDIA_ROOT = os.path.abspath( os.path.join(TMP_ROOT, 'media') )
\ No newline at end of file
+MEDIA_ROOT = os.path.abspath( os.path.join(TMP_ROOT, 'media') )
+MEDIA_URL = '/media/'
\ No newline at end of file
